==> seedsui-react-5.5.92.tgz: package/lib/Jcrop/原代码/sticker.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

/* This class creates a draggable frame by locking the
   corner opposite to the one being dragged */
import Rect from "./rect";

var Sticker = /*#__PURE__*/function () {
  function Sticker(rect, w, h, ord) {
    _classCallCheck(this, Sticker);

    this.sw = w;
    this.sh = h;
    this.rect = rect;
    this.locked = this.getCornerPoint(this.getOppositeCorner(ord));
    this.stuck = this.getCornerPoint(ord);
  }

  _createClass(Sticker, [{
    key: "move",
    value: function move(x, y) {
      return Rect.fromPoints(this.locked, this.translateStuckPoint(x, y));
    } // Determine "quadrant" of handle drag relative to locked point
    // returns string tl = top left, br = bottom right, etc

  }, {
    key: "getDragQuadrant",
    value: function getDragQuadrant(x, y) {
      var relx = this.locked[0] - x;
      var rely = this.locked[1] - y;
      if (relx < 0 && rely < 0) return 'br';else if (relx >= 0 && rely >= 0) return 'tl';else if (relx < 0 && rely >= 0) return 'tr';else return 'bl';
    } // get the maximum aspect ratio rectangle for the current drag

  }, {
    key: "getMaxRect",
    value: function getMaxRect(x, y, aspect) {
      return Rect.getMax(Math.abs(this.locked[0] - x), Math.abs(this.locked[1] - y), aspect);
    } // given the offset of the drag versus the stuck point,
    // determine the real dragging coordinates

  }, {
    key: "translateStuckPoint",
    value: function translateStuckPoint(ox, oy) {
      var _this$stuck = _slicedToArray(this.stuck, 3),
          xx = _this$stuck[0],
          yy = _this$stuck[1],
          sp = _this$stuck[2];

      var x = xx === null ? sp : xx + ox;
      var y = yy === null ? sp : yy + oy;
      if (x > this.sw) x = this.sw;
      if (y > this.sh) y = this.sh;
      if (x < 0) x = 0;
      if (y < 0) y = 0;

      if (this.aspect) {
        var _this$getMaxRect = this.getMaxRect(x, y, this.aspect),
            _this$getMaxRect2 = _slicedToArray(_this$getMaxRect, 2),
            w = _this$getMaxRect2[0],
            h = _this$getMaxRect2[1];

        var quad = this.getDragQuadrant(x, y);
        var res = Rect.fromPoint(this.locked, w, h, quad);
        return [res.x2, res.y2];
      }

      return [x, y];
    }
  }, {
    key: "getCornerPoint",
    value: function getCornerPoint(h) {
      var p = this.rect;

      switch (h) {
        case 'n':
          return [null, p.y, p.x];

        case 's':
          return [null, p.y2, p.x2];

        case 'e':
          return [p.x2, null, p.y2];

        case 'w':
          return [p.x, null, p.y];

        case 'se':
          return [p.x2, p.y2];

        case 'sw':
          return [p.x, p.y2];

        case 'ne':
          return [p.x2, p.y];

        case 'nw':
          return [p.x, p.y];
      }
    }
  }, {
    key: "getOppositeCorner",
    value: function getOppositeCorner(h) {
      switch (h) {
        case 'n':
          return 'se';

        case 's':
          return 'nw';

        case 'e':
          return 'nw';

        case 'w':
          return 'se';

        case 'se':
          return 'nw';

        case 'sw':
          return 'ne';

        case 'ne':
          return 'sw';

        case 'nw':
          return 'se';
      }
    }
  }]);

  return Sticker;
}();

Sticker.create = function (rect, w, h, ord) {
  return new Sticker(rect, w, h, ord);
};

export default Sticker;

==> seedsui-react-5.6.70.tgz: package/lib/Jcrop/原代码/sticker.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
/* This class creates a draggable frame by locking the
   corner opposite to the one being dragged */

import Rect from "./rect";
var Sticker = /*#__PURE__*/function () {
  function Sticker(rect, w, h, ord) {
    _classCallCheck(this, Sticker);
    this.sw = w;
    this.sh = h;
    this.rect = rect;
    this.locked = this.getCornerPoint(this.getOppositeCorner(ord));
    this.stuck = this.getCornerPoint(ord);
  }
  _createClass(Sticker, [{
    key: "move",
    value: function move(x, y) {
      return Rect.fromPoints(this.locked, this.translateStuckPoint(x, y));
    }

    // Determine "quadrant" of handle drag relative to locked point
    // returns string tl = top left, br = bottom right, etc
  }, {
    key: "getDragQuadrant",
    value: function getDragQuadrant(x, y) {
      var relx = this.locked[0] - x;
      var rely = this.locked[1] - y;
      if (relx < 0 && rely < 0) return 'br';else if (relx >= 0 && rely >= 0) return 'tl';else if (relx < 0 && rely >= 0) return 'tr';else return 'bl';
    }

    // get the maximum aspect ratio rectangle for the current drag
  }, {
    key: "getMaxRect",
    value: function getMaxRect(x, y, aspect) {
      return Rect.getMax(Math.abs(this.locked[0] - x), Math.abs(this.locked[1] - y), aspect);
    }

    // given the offset of the drag versus the stuck point,
    // determine the real dragging coordinates
  }, {
    key: "translateStuckPoint",
    value: function translateStuckPoint(ox, oy) {
      var _this$stuck = _slicedToArray(this.stuck, 3),
        xx = _this$stuck[0],
        yy = _this$stuck[1],
        sp = _this$stuck[2];
      var x = xx === null ? sp : xx + ox;
      var y = yy === null ? sp : yy + oy;
      if (x > this.sw) x = this.sw;
      if (y > this.sh) y = this.sh;
      if (x < 0) x = 0;
      if (y < 0) y = 0;
      if (this.aspect) {
        var _this$getMaxRect = this.getMaxRect(x, y, this.aspect),
          _this$getMaxRect2 = _slicedToArray(_this$getMaxRect, 2),
          w = _this$getMaxRect2[0],
          h = _this$getMaxRect2[1];
        var quad = this.getDragQuadrant(x, y);
        var res = Rect.fromPoint(this.locked, w, h, quad);
        return [res.x2, res.y2];
      }
      return [x, y];
    }
  }, {
    key: "getCornerPoint",
    value: function getCornerPoint(h) {
      var p = this.rect;
      switch (h) {
        case 'n':
          return [null, p.y, p.x];
        case 's':
          return [null, p.y2, p.x2];
        case 'e':
          return [p.x2, null, p.y2];
        case 'w':
          return [p.x, null, p.y];
        case 'se':
          return [p.x2, p.y2];
        case 'sw':
          return [p.x, p.y2];
        case 'ne':
          return [p.x2, p.y];
        case 'nw':
          return [p.x, p.y];
      }
    }
  }, {
    key: "getOppositeCorner",
    value: function getOppositeCorner(h) {
      switch (h) {
        case 'n':
          return 'se';
        case 's':
          return 'nw';
        case 'e':
          return 'nw';
        case 'w':
          return 'se';
        case 'se':
          return 'nw';
        case 'sw':
          return 'ne';
        case 'ne':
          return 'sw';
        case 'nw':
          return 'se';
      }
    }
  }]);
  return Sticker;
}();
Sticker.create = function (rect, w, h, ord) {
  return new Sticker(rect, w, h, ord);
};
export default Sticker;
